==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACharBaseType.h <==
// public final class soot.jimple.parser.node.ACharBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 77e9d3fcb0a120a1 soot_jimple_parser_node_ACharBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ACharBaseType_H_
#define _JC_soot_jimple_parser_node_ACharBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TChar$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$sub_refs	_jc_soot_jimple_parser_node_ACharBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ACharBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$refs	_jc_soot_jimple_parser_node_ACharBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$nonrefs	_jc_soot_jimple_parser_node_ACharBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$object	_jc_soot_jimple_parser_node_ACharBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ACharBaseType$vmethods	_jc_soot_jimple_parser_node_ACharBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACharBaseType$vtable	_jc_soot_jimple_parser_node_ACharBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACharBaseType$vtype	_jc_soot_jimple_parser_node_ACharBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *);
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$_init$ce58a2ab899dce8d(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_TChar$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACharBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TChar$object *_jc_soot_jimple_parser_node_ACharBaseType$method$getChar$72a27a7f92e9d2a4(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *);
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$setChar$72302f161c46f395(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_TChar$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACharBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$getChar$72a27a7f92e9d2a4;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$setChar$72302f161c46f395;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACharBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *);
	struct _jc_soot_jimple_parser_node_TChar$object	*(*getChar$72a27a7f92e9d2a4)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setChar$72302f161c46f395)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_TChar$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACharBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ACharBaseType$vmethods	soot_jimple_parser_node_ACharBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACharBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACharBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACharBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TChar$object	*__5fchar__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACharBaseType$refs {
    _jc_soot_jimple_parser_node_ACharBaseType$sub_refs	soot_jimple_parser_node_ACharBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACharBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACharBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ACharBaseType$sub_nonrefs	soot_jimple_parser_node_ACharBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACharBaseType$object {
	_jc_soot_jimple_parser_node_ACharBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACharBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACharBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACharBaseType$vtype _jc_soot_jimple_parser_node_ACharBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACharBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACharBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACharBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACharBaseType.h <==
// public final class soot.jimple.parser.node.ACharBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 77e9d3fcb0a120a1 soot_jimple_parser_node_ACharBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ACharBaseType_H_
#define _JC_soot_jimple_parser_node_ACharBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TChar$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$sub_refs	_jc_soot_jimple_parser_node_ACharBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ACharBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$refs	_jc_soot_jimple_parser_node_ACharBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$nonrefs	_jc_soot_jimple_parser_node_ACharBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACharBaseType$object	_jc_soot_jimple_parser_node_ACharBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ACharBaseType$vmethods	_jc_soot_jimple_parser_node_ACharBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACharBaseType$vtable	_jc_soot_jimple_parser_node_ACharBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACharBaseType$vtype	_jc_soot_jimple_parser_node_ACharBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$_init$ce58a2ab899dce8d(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACharBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TChar$object *_jc_soot_jimple_parser_node_ACharBaseType$method$getChar$72a27a7f92e9d2a4(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACharBaseType$method$setChar$72302f161c46f395(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACharBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$getChar$72a27a7f92e9d2a4;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$setChar$72302f161c46f395;
extern _jc_method _jc_soot_jimple_parser_node_ACharBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACharBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TChar$object	*(*getChar$72a27a7f92e9d2a4)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setChar$72302f161c46f395)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACharBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACharBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ACharBaseType$vmethods	soot_jimple_parser_node_ACharBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACharBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACharBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACharBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TChar$object	*__5fchar__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACharBaseType$refs {
    _jc_soot_jimple_parser_node_ACharBaseType$sub_refs	soot_jimple_parser_node_ACharBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACharBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACharBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ACharBaseType$sub_nonrefs	soot_jimple_parser_node_ACharBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACharBaseType$object {
	_jc_soot_jimple_parser_node_ACharBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACharBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACharBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACharBaseType$vtype _jc_soot_jimple_parser_node_ACharBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACharBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACharBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACharBaseType_H_ */
